PyACI: Python Bindings for Cisco ACI REST API
=============================================
.. image:: https://codecov.io/gh/datacenter/pyaci/branch/master/graph/badge.svg
   :alt: codecov status
   :target: https://codecov.io/gh/datacenter/pyaci

.. image:: https://readthedocs.org/projects/pyaci/badge/?version=latest&style=plastic
   :alt: Doc Status
   :target: http://pyaci.readthedocs.io/en/latest/

Documentation
-------------

Documentation is available at http://pyaci.readthedocs.io/en/latest/

Examples
--------

Jupyter Notebook based examples can be found in `examples <examples>`_ directory.
